@@ -38,10 +38,6 @@ def text_input(question, initial_answer,
     :type button: str, optional
     :return: tuple of booleans with button press status and correctness of answer
     :rtype: tuple of bool
-
-    Example:
-    import streamlit_book as stb
-    stb.text_input("What is your name?", "", equals="Me")
     """
     user_answer = st.text_input(question, initial_answer)
     # Check if the correct checkboxes are checked
