@@ -28,24 +28,15 @@ def true_or_false(question, answer,
     :type button: str, optional
     :return: tuple of booleans(button_pressed, answer_correct) with the button status and correctness of answer
     :rtype: tuple of bool
-
-    Example:
-    import streamlit_book as stb
-    stb.true_or_false('Is "Indiana Jones and the Last Crusade" the best movie of the trilogy?',
-                        True,
-                        success="You have chosen wisely",
-                        error="You have chosen poorly",
-                        button="You must choose"
-                        )
     """
     if len(question)==0:
         st.error("Please provide a question")
         return None, None
     else:
         key = question.lower().replace(" ","")
-        user_answer = st.radio(question, options=["True", "False"], key=key)
-        user_answer = (user_answer == "True") # Convert to boolean
-        if st.button(button, key=key):
+        user_answer_str = st.radio(question, options=["True", "False"], key="TF"+key)
+        user_answer = (user_answer_str == "True") # Convert to boolean
+        if st.button(button, key="button"+key):
             # Reveal the answer
             if user_answer == answer:
                 if success: 
